@@ -519,7 +519,7 @@ proc GraphConfigure { interpName graphName } {
 }
 
 proc ResetGraph {} {
-    global graphOptions graphDefaults graph interp
+    global graphOptions graphDefaults graph interp class
 
     RGBColorReset graph -background $graphOptions(-background)
     IntReset graph -borderwidth $graphOptions(-borderwidth)
@@ -528,6 +528,7 @@ proc ResetGraph {} {
     EntryReset graph -font $graphOptions(-font)
     RGBColorReset graph -foreground $graphOptions(-foreground)
     IntReset graph -height $graphOptions(-height)
+    BooleanReset graph -invertxy $graphOptions(-invertxy)
     IntReset graph -leftmargin $graphOptions(-leftmargin)
     RGBColorReset graph -plotbackground $graphOptions(-plotbackground)
     IntReset graph -plotborderwidth $graphOptions(-plotborderwidth)
@@ -553,7 +554,7 @@ proc GetGraph {} {
 
 
 proc ConfigureGeneral {} {
-    global graphOptions graphDefaults 
+    global graphOptions graphDefaults class
     global table row column setProc getProc 
     
     set name graph
@@ -580,6 +581,7 @@ proc ConfigureGeneral {} {
     EntryControl graph -font $graphOptions(-font)
     RGBColorControl graph -foreground $graphOptions(-foreground)
     IntControl graph -height 150 800 $graphOptions(-height)
+    BooleanControl graph -invertxy $graphOptions(-invertxy)
     IntControl graph -leftmargin 0 100 $graphOptions(-leftmargin)
     set row 2
     set column 5
@@ -597,6 +599,9 @@ proc ConfigureGeneral {} {
     button $table($name).button_reset -text "reset" \
 	-command "ResetGraph"
     incr row
+    if { $row & 1 } {
+	incr row
+    }
     blt_table $table($name) \
 	$table($name).frame 0,0 -cspan 14 -rspan $row -fill both \
 	-padx 4 -pady 4 \
@@ -615,6 +620,7 @@ proc ResetAxis { axis } {
     global axisOptions axisDefaults graph interp
 
     RGBColorReset axis -color $axisOptions(-color)
+    BooleanReset axis -descending $axisOptions(-descending)
     EntryReset axis -font $axisOptions(-font)
     IntReset axis -linewidth $axisOptions(-linewidth)
     BooleanReset axis -logscale $axisOptions(-logscale)
@@ -694,6 +700,7 @@ proc ConfigureAxis {} {
 	$table($name).axis.y2 { left expand fill } 
 
     RGBColorControl axis -color $axisOptions(-color)
+    BooleanControl axis -descending $axisOptions(-descending)
     EntryControl axis -font $axisOptions(-font)
     IntControl axis -linewidth 0 10 $axisOptions(-linewidth)
     BooleanControl axis -logscale $axisOptions(-logscale)
