@@ -4,7 +4,7 @@
  *	This module implements a background "exec" command for the
  *	Tk toolkit.
  *
- * Copyright 1993 by AT&T Bell Laboratories.
+ * Copyright 1993-1994 by AT&T Bell Laboratories.
  * Permission to use, copy, modify, and distribute this software
  * and its documentation for any purpose and without fee is hereby
  * granted, provided that the above copyright notice appear in all
@@ -87,6 +87,7 @@ typedef struct {
 
 #ifndef sun
 extern char *strdup _ANSI_ARGS_((CONST char *s));
+
 #endif
 
 /*
@@ -178,7 +179,6 @@ GrowBuffer(bufferPtr)
 
     bufferPtr->size += bufferPtr->size;
     newPtr = (char *)malloc(sizeof(char) * (bufferPtr->size + 1));
-
     if (newPtr == NULL) {
 	return TCL_ERROR;
     }
@@ -285,6 +285,7 @@ FixNewline(infoPtr)
     infoPtr->fixMark = -1;
     if (bufferPtr->used > 0) {
 	int mark = bufferPtr->used - 1;
+
 	if (bufferPtr->storage[mark] == '\n') {
 	    bufferPtr->storage[mark] = '\0';
 	    infoPtr->fixMark = mark;
@@ -442,7 +443,7 @@ CleanupProc(clientData, interp, part1, part2, flags)
 
 	    if (result == TCL_OK) {
 		if (!infoPtr->keepFlag) {
-		    FixNewline(&(infoPtr->buffer));
+		    FixNewline(infoPtr);
 		}
 		Tcl_SetVar2(infoPtr->interp, infoPtr->errorName, (char *)NULL,
 		    GetBuffer(&(infoPtr->buffer)), TCL_GLOBAL_ONLY);
@@ -517,9 +518,9 @@ BackgroundProc(clientData, mask)
 		FixNewline(infoPtr);
 	    }
 	    Tcl_SetVar2(infoPtr->interp, infoPtr->updateName, (char *)NULL,
-		GetLastAppended(infoPtr),(TCL_GLOBAL_ONLY | TCL_APPEND_VALUE));
+		GetLastAppended(infoPtr), (TCL_GLOBAL_ONLY | TCL_APPEND_VALUE));
 	    if (!infoPtr->keepFlag) {
-		UnfixNewline(&(infoPtr->buffer));
+		UnfixNewline(infoPtr);
 	    }
 	}
 	return;
@@ -534,7 +535,7 @@ BackgroundProc(clientData, mask)
      * In either case, set the variable to trigger the cleanup procedure.
      */
     if (!infoPtr->keepFlag) {
-	FixNewline(&(infoPtr->buffer));
+	FixNewline(infoPtr);
     }
     if (infoPtr->updateName != NULL) {
 	Tcl_SetVar2(infoPtr->interp, infoPtr->updateName, (char *)NULL,
@@ -586,10 +587,8 @@ BgExecCmd(clientData, interp, argc, argv)
 	return TCL_ERROR;
     }
     infoPtr = (BackgroundInfo *)malloc(sizeof(BackgroundInfo));
-
     if (infoPtr == NULL) {
-	Tcl_AppendResult(interp, "can't allocate file info structure: ",
-	    Tcl_PosixError(interp), (char *)NULL);
+	interp->result = "can't allocate file info structure";
 	return TCL_ERROR;
     }
     infoPtr->interp = interp;
