@@ -27,7 +27,7 @@
  *  AUTHOR:  Michael J. McLennan       Phone: (215)770-2842
  *           AT&T Bell Laboratories   E-mail: aluxpo!mmc@att.com
  *
- *     RCS:  bltDragDrop.c,v 1.7 1994/01/10 21:41:05 gah Exp
+ *     RCS:  bltDragDrop.c,v 1.8 1994/01/18 21:29:51 gah Exp
  * ========================================================================
  *                 Copyright (c) 1993-1994  AT&T Bell Laboratories
  * ========================================================================
@@ -53,9 +53,15 @@
 #include <X11/Xatom.h>
 
 #ifndef DRAGDROP_VERSION
-#define DRAGDROP_VERSION "2.0"
+#define DRAGDROP_VERSION "2.1"
 #endif
 
+#define DRAGDROP_COMMAND	"blt_drag&drop"   /* Command name */
+#define DRAGDROP_CLASS		"DragDrop"  	  /* CLASS NAME for token window */
+#define DRAGDROP_PROPINFO	"BltDragDropInfo" /* Property name */
+#define DRAGDROP_ERRORPROC	"tkerror"		  /* Error Proc used to report 
+											   * drag&drop background errors */
+
 #ifndef _BLT_H
 /*
  *  -------------  The following color definitions are taken directly
@@ -69,13 +75,15 @@
 #define BISQUE1     "#ffe4c4"
 #define BISQUE2     "#eed5b7"
 #define BISQUE3     "#cdb79e"
-#endif
+#endif							/* _BLT_H */
 #define DEF_BUTTON_ACTIVE_BG_COLOR  BISQUE2
 #define DEF_BUTTON_ACTIVE_BG_MONO   BLACK
 #define DEF_BUTTON_ACTIVE_FG_COLOR  BLACK
 #define DEF_BUTTON_ACTIVE_FG_MONO   WHITE
 #define DEF_BUTTON_BG_COLOR     BISQUE1
 #define DEF_BUTTON_BG_MONO      WHITE
+#define DEF_TOKEN_OUTLINE_COLOR     BLACK
+#define DEF_TOKEN_OUTLINE_MONO      BLACK
 
 /*
  *  DRAG&DROP ROOT WINDOW HIERARCHY (cached during "drag" operations)
@@ -239,6 +247,15 @@ static Tk_ConfigSpec SourceConfigSpecs[] = {
 		DEF_BUTTON_BG_MONO, Tk_Offset(DD_Source, tokenBorder),
 		TK_CONFIG_MONO_ONLY},
 
+	{TK_CONFIG_BORDER,
+		"-tokenoutline", "tokenOutline", "Outline",
+		DEF_TOKEN_OUTLINE_COLOR, Tk_Offset(DD_Source, tokenOutline),
+		TK_CONFIG_COLOR_ONLY},
+	{TK_CONFIG_BORDER,
+		"-tokenoutline", "tokenOutline", "Outline",
+		DEF_TOKEN_OUTLINE_MONO, Tk_Offset(DD_Source, tokenOutline),
+		TK_CONFIG_MONO_ONLY},
+
 	{TK_CONFIG_PIXELS,
 		"-tokenborderwidth", "tokenBorderWidth", "BorderWidth",
 		"3", Tk_Offset(DD_Source, tokenBorderWidth),
@@ -255,33 +272,13 @@ static Tk_ConfigSpec SourceConfigSpecs[] = {
 		0},
 };
 
-/*
- *  COMMAND NAME
- */
-static char *DragDropCmdName = "blt_drag&drop";
-
-/*
- *  CLASS NAME for token window
- */
-static char *TokenClassName = "DragDrop";
-
-/*
- *  PROPERTY NAME
- */
-static char *DragDropInfo = "BltDragDropInfo";
-
-/*
- *  ERROR PROC used to report drag&drop background errors
- */
-static char *DragDropErrProc = "tkerror";
-
 
 /*
  *  DRAG&DROP TARGET REGISTRATION RECORD
  */
 typedef struct DD_TargetHndl {
-	char *dataType;               /* name of data type */
-	char *command;                /* command to handle data type */
+	char *dataType;               /* Name of data type (malloc-ed) */
+	char *command;                /* command to handle data type (malloc-ed) */
 	struct DD_TargetHndl* next;   /* next handler in linked list */
 } DD_TargetHndl;
 
@@ -379,6 +376,10 @@ static void StackDelete _ANSI_ARGS_((DD_Stack *stack));
 static void StackPush _ANSI_ARGS_((ClientData cdata, DD_Stack *stack));
 static ClientData StackPop _ANSI_ARGS_((DD_Stack *stack));
 
+#ifndef sun
+extern char *strdup _ANSI_ARGS_((CONST char *s));
+#endif
+
 
 
 /*
@@ -401,11 +402,11 @@ Blt_DragDropInit(interp)
 	/*
 	 *  See if drag&drop is already installed.
 	 */
-	if (Tcl_GetCommandInfo(interp, DragDropCmdName, &cmdInfo))
+	if (Tcl_GetCommandInfo(interp, DRAGDROP_COMMAND, &cmdInfo))
 	{
 		Tcl_ResetResult(interp);
-		Tcl_AppendResult(interp, "already installed: ", DragDropCmdName,
-			(char*)NULL);
+		Tcl_AppendResult(interp, "already installed: ", DRAGDROP_COMMAND,
+						 (char*)NULL);
 		return TCL_ERROR;
 	}
 
@@ -416,29 +417,28 @@ Blt_DragDropInit(interp)
 	if (tkwin == None)
 	{
 		Tcl_ResetResult(interp);
-		Tcl_AppendResult(interp, "requires Tk facilities: ",
-			DragDropCmdName, (char*)NULL);
+		Tcl_AppendResult(interp, "requires Tk facilities: ", DRAGDROP_COMMAND,
+						 (char*)NULL);
 		return TCL_ERROR;
 	}
 
 	/*
 	 *  Install drag&drop facilities.
 	 */
-    ddlist = (DD_RegList*)ckalloc(sizeof(DD_RegList));
+    ddlist = (DD_RegList*)malloc(sizeof(DD_RegList));
     ddlist->interp = interp;
     ddlist->root = tkwin;
     Tcl_InitHashTable(&ddlist->srcList,TCL_STRING_KEYS);
     Tcl_InitHashTable(&ddlist->trgList,TCL_STRING_KEYS);
-    ddlist->errorProc = (char*)ckalloc((unsigned)(strlen(DragDropErrProc)+1));
-	strcpy(ddlist->errorProc, DragDropErrProc);
+    ddlist->errorProc = strdup(DRAGDROP_ERRORPROC);
     ddlist->numactive = 0;
     ddlist->locx = ddlist->locy = 0;
     ddlist->pool = NULL;
 
-	Tcl_CreateCommand(interp, DragDropCmdName, DragDrop_Cmd,
+	Tcl_CreateCommand(interp, DRAGDROP_COMMAND, DragDrop_Cmd,
 		(ClientData)ddlist, DragDrop_Delete);
 
-	Tcl_SetVar2(interp, "blt_versions", "blt_dragdrop", DRAGDROP_VERSION,
+	Tcl_SetVar2(interp, "blt_versions", DRAGDROP_COMMAND, DRAGDROP_VERSION,
 		TCL_GLOBAL_ONLY);
 
 	return TCL_OK;
@@ -461,14 +461,15 @@ DragDrop_Delete(cdata)
 
     Tcl_DeleteHashTable(&ddlist->srcList);
     Tcl_DeleteHashTable(&ddlist->trgList);
-	ckfree((char*)ddlist->errorProc);
-
+	if (ddlist->errorProc != NULL) {
+		free((char*)ddlist->errorProc);
+	}
 	for (wrpool=ddlist->pool; wrpool; wrpool=wrnext)
 	{
 		wrnext = wrpool->next;
-		ckfree((char*)wrpool);
+		free((char*)wrpool);
 	}
-	ckfree((char*)ddlist);
+	free((char*)ddlist);
 }
 
 /*
@@ -565,7 +566,7 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 			return TCL_ERROR;
 		}
 		dsPtr->display = Tk_Display(dsPtr->tkwin);
-		dsPtr->ddAtom  = XInternAtom(dsPtr->display, DragDropInfo, False);
+		dsPtr->ddAtom  = XInternAtom(dsPtr->display, DRAGDROP_PROPINFO, False);
 
 		if (newEntry)
 			ConfigSource(interp, dsPtr, 0, (char**)NULL, 0);
@@ -666,7 +667,7 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 				DestroySourceInfo(ddlist,argv[2]);
 				return TCL_ERROR;
 			}
-			Tk_SetClass(tokenwin,TokenClassName);
+			Tk_SetClass(tokenwin, DRAGDROP_CLASS);
 			Tk_CreateEventHandler(tokenwin, ExposureMask|StructureNotifyMask,
 				DDTokenEventProc, (ClientData)dsPtr);
 
@@ -684,9 +685,9 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 					"bind %.100s <ButtonPress-%d> {%s drag %.100s %%X %%Y}; \
 					bind %.100s <B%d-Motion> {%s drag %.100s %%X %%Y}; \
 					bind %.100s <ButtonRelease-%d> {%s drop %.100s %%X %%Y}",
-					argv[2], dsPtr->button, DragDropCmdName, argv[2],
-					argv[2], dsPtr->button, DragDropCmdName, argv[2],
-					argv[2], dsPtr->button, DragDropCmdName, argv[2]);
+					argv[2], dsPtr->button, DRAGDROP_COMMAND, argv[2],
+					argv[2], dsPtr->button, DRAGDROP_COMMAND, argv[2],
+					argv[2], dsPtr->button, DRAGDROP_COMMAND, argv[2]);
 
 				if (Tcl_Eval(interp, buffer) != TCL_OK)
 				{
@@ -700,7 +701,7 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 			 *  Arrange for the window to unregister itself when it
 			 *  is destroyed.
 			 */
-			ddentry = (DD_RegEntry*)ckalloc(sizeof(DD_RegEntry));
+			ddentry = (DD_RegEntry*)malloc(sizeof(DD_RegEntry));
 			ddentry->ddlist = ddlist;
 			ddentry->tkwin = dsPtr->tkwin;
 			Tk_CreateEventHandler(dsPtr->tkwin, StructureNotifyMask,
@@ -755,7 +756,7 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 			 *  Arrange for the window to unregister itself when it
 			 *  is destroyed.
 			 */
-			ddentry = (DD_RegEntry*)ckalloc(sizeof(DD_RegEntry));
+			ddentry = (DD_RegEntry*)malloc(sizeof(DD_RegEntry));
 			ddentry->ddlist = ddlist;
 			ddentry->tkwin = dtPtr->tkwin;
 			Tk_CreateEventHandler(dtPtr->tkwin, StructureNotifyMask,
@@ -906,10 +907,8 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 			 *  Save result of token command for send command.
 			 */
 			if (dsPtr->pkgcmdResult)
-				ckfree(dsPtr->pkgcmdResult);
-			dsPtr->pkgcmdResult
-				= (char*)ckalloc((unsigned)(strlen(interp->result)+1));
-			strcpy(dsPtr->pkgcmdResult, interp->result);
+				free(dsPtr->pkgcmdResult);
+			dsPtr->pkgcmdResult = strdup(interp->result);
 
 			/*
 			 *  Token building failed?  If an error handler is defined,
@@ -1051,9 +1050,10 @@ DragDrop_Cmd(clientData, interp, argc, argv)
 	{
 		if (argc == 3)
 		{
-			ckfree(ddlist->errorProc);
-    		ddlist->errorProc = (char*)ckalloc((unsigned)(strlen(argv[2])+1));
-			strcpy(ddlist->errorProc, argv[2]);
+			if (ddlist->errorProc) {
+				free(ddlist->errorProc);
+			}
+    		ddlist->errorProc = strdup(argv[2]);
 		}
 		else if (argc != 2)
 		{
@@ -1148,7 +1148,7 @@ GetSourceInfo(ddlist,pathname,newEntry)
 		/*
 		 *  Initialize a data structure for the widget...
 		 */
-		dsPtr = (DD_Source*)ckalloc(sizeof(DD_Source));
+		dsPtr = (DD_Source*)malloc(sizeof(DD_Source));
 		dsPtr->ddlist = ddlist;
 		dsPtr->display = NULL;
 		dsPtr->tkwin = NULL;
@@ -1197,40 +1197,35 @@ GetSourceInfo(ddlist,pathname,newEntry)
  */
 static void
 DestroySourceInfo(ddlist,pathname)
-	DD_RegList* ddlist;  /* drag&drop records for all registered widgets */
-	char* pathname;      /* widget pathname for desired record */
+	DD_RegList* ddlist;	 /* drag&drop records for all registered widgets */
+	char* pathname;		 /* widget pathname for desired record */
 {
 	DD_Source *dsPtr;
 	DD_SourceHndl *dsHndl, *next;
 	Tcl_HashEntry *ddEntry;
 
 	ddEntry = Tcl_FindHashEntry(&ddlist->srcList, pathname);
-	dsPtr = (ddEntry) ? (DD_Source*)Tcl_GetHashValue(ddEntry) : NULL;
-
+	if (ddEntry == NULL) {
+		return;
+	}
+	dsPtr = (DD_Source*)Tcl_GetHashValue(ddEntry);
 	if (dsPtr)
 	{
 		Tk_CancelIdleCall(UpdateDDToken, (ClientData)dsPtr);
+		if (dsPtr->hidetoken)		   
+			Tk_DeleteTimerHandler(dsPtr->hidetoken);
 
-		if (dsPtr->tokenOutline)       Tk_Free3DBorder(dsPtr->tokenOutline);
-		if (dsPtr->tokenBorder)        Tk_Free3DBorder(dsPtr->tokenBorder);
-		if (dsPtr->hidetoken)          Tk_DeleteTimerHandler(dsPtr->hidetoken);
-		if (dsPtr->rejectFg)           Tk_FreeColor(dsPtr->rejectFg);
-		if (dsPtr->rejectBg)           Tk_FreeColor(dsPtr->rejectBg);
-		if (dsPtr->rejectSt != None)   Tk_FreeBitmap(dsPtr->display,
-		                                 dsPtr->rejectSt);
-		if (dsPtr->rejectFgGC != None) Tk_FreeGC(dsPtr->display,
-		                                 dsPtr->rejectFgGC);
-		if (dsPtr->rejectBgGC != None) Tk_FreeGC(dsPtr->display,
-		                                 dsPtr->rejectBgGC);
-		if (dsPtr->send)               ckfree(dsPtr->send);
-		if (dsPtr->pkgcmd)             ckfree(dsPtr->pkgcmd);
-		if (dsPtr->pkgcmdResult)       ckfree(dsPtr->pkgcmdResult);
-		if (dsPtr->sitecmd)            ckfree(dsPtr->sitecmd);
+		Tk_FreeOptions(SourceConfigSpecs, (char *)dsPtr, dsPtr->display, 0);
 
-		if (dsPtr->allwins)            WinRepRelease(dsPtr->allwins, ddlist);
+		if (dsPtr->rejectFgGC != None) 
+			Tk_FreeGC(dsPtr->display, dsPtr->rejectFgGC);
+		if (dsPtr->rejectBgGC != None) 
+			Tk_FreeGC(dsPtr->display, dsPtr->rejectBgGC);
+		if (dsPtr->pkgcmdResult)	   
+			free(dsPtr->pkgcmdResult);
 
-		if (dsPtr->tokenCursor != None)
-			Tk_FreeCursor(dsPtr->display, dsPtr->tokenCursor);
+		if (dsPtr->allwins)			   
+			WinRepRelease(dsPtr->allwins, ddlist);
 
 		if (dsPtr->normalCursor != None)
 			Tk_FreeCursor(dsPtr->display, dsPtr->normalCursor);
@@ -1242,9 +1237,9 @@ DestroySourceInfo(ddlist,pathname)
 			DestroySourceHandler(dsHndl);
 			dsHndl = next;
 		}
-		ckfree((char*)dsPtr);
+		free((char*)dsPtr);
 	}
-	if (ddEntry) Tcl_DeleteHashEntry(ddEntry);
+	Tcl_DeleteHashEntry(ddEntry);
 }
 
 /*
@@ -1284,14 +1279,6 @@ ConfigSource(interp, dsPtr, argc, argv, flags)
 			TCL_STATIC);
 		return TCL_ERROR;
 	}
-
-	/*
-	 *  Create a border for the outline of the token window...
-	 */
-	if (!dsPtr->tokenOutline)
-		dsPtr->tokenOutline = Tk_Get3DBorder(dsPtr->ddlist->interp,
-			dsPtr->tkwin, None, Tk_GetUid("black"));
-
 	/*
 	 *  Set up the rejection foreground GC for the token window...
 	 */
@@ -1391,9 +1378,10 @@ PutSourceHandler(dsPtr, dtname, cmd)
 			}
 			else
 			{
-				ckfree(dsHndl->cmd);
-				dsHndl->cmd = (char*)ckalloc((unsigned)(strlen(cmd)+1));
-				strcpy(dsHndl->cmd, cmd);
+				if (dsHndl->cmd != NULL) {
+					free(dsHndl->cmd);
+				}
+				dsHndl->cmd = strdup(cmd);
 				return;
 			}
 		}
@@ -1417,14 +1405,10 @@ CreateSourceHandler(dtname, cmd)
 	char *cmd;                 /* command used to send data */
 {
 	DD_SourceHndl *retn;
-	retn = (DD_SourceHndl*)ckalloc(sizeof(DD_SourceHndl));
-
-	retn->dataType = (char*)ckalloc((unsigned)(strlen(dtname)+1));
-	strcpy(retn->dataType, dtname);
-
-	retn->cmd = (char*)ckalloc((unsigned)(strlen(cmd)+1));
-	strcpy(retn->cmd, cmd);
+	retn = (DD_SourceHndl*)malloc(sizeof(DD_SourceHndl));
 
+	retn->dataType = strdup(dtname);
+	retn->cmd = strdup(cmd);
 	retn->next = NULL;
 	return retn;
 }
@@ -1440,9 +1424,13 @@ static void
 DestroySourceHandler(dsHndl)
 	DD_SourceHndl *dsHndl;
 {
-	ckfree(dsHndl->dataType);
-	ckfree(dsHndl->cmd);
-	ckfree((char*)dsHndl);
+	if (dsHndl->dataType != NULL) {
+		free(dsHndl->dataType);
+	}
+	if (dsHndl->cmd != NULL) {
+		free(dsHndl->cmd);
+	}
+	free((char*)dsHndl);
 }
 
 /*
@@ -1465,7 +1453,7 @@ UnregSource(cdata, eventPtr)
 	if (eventPtr->type == DestroyNotify)
 	{
 		DestroySourceInfo(ddlist,ddname);
-		ckfree((char*)ddentry);
+		free((char*)ddentry);
 	}
 }
 
@@ -1493,7 +1481,7 @@ GetTargetInfo(ddlist,pathname,newEntry)
 		/*
 		 *  Initialize a data structure for the widget...
 		 */
-		dtPtr = (DD_Target*)ckalloc(sizeof(DD_Target));
+		dtPtr = (DD_Target*)malloc(sizeof(DD_Target));
 		dtPtr->ddlist = ddlist;
 		dtPtr->display = NULL;
 		dtPtr->tkwin = NULL;
@@ -1533,7 +1521,7 @@ DestroyTargetInfo(ddlist,pathname)
 			DestroyTargetHandler(dtHndl);
 			dtHndl = next;
 		}
-		ckfree((char*)dtPtr);
+		free((char*)dtPtr);
 	}
 	if (ddEntry) Tcl_DeleteHashEntry(ddEntry);
 }
@@ -1594,9 +1582,10 @@ PutTargetHandler(dtPtr, dtname, cmd)
 			}
 			else
 			{
-				ckfree(dtHndl->command);
-				dtHndl->command = (char*)ckalloc((unsigned)(strlen(cmd)+1));
-				strcpy(dtHndl->command, cmd);
+				if (dtHndl->command != NULL) {
+					free(dtHndl->command);
+				}
+				dtHndl->command = strdup(cmd);
 				return;
 			}
 		}
@@ -1625,13 +1614,10 @@ CreateTargetHandler(dtname, cmd)
 	char *cmd;                 /* command string for data type */
 {
 	DD_TargetHndl *retn;
-	retn = (DD_TargetHndl*)ckalloc(sizeof(DD_TargetHndl));
+	retn = (DD_TargetHndl*)malloc(sizeof(DD_TargetHndl));
 
-	retn->dataType = (char*)ckalloc((unsigned)(strlen(dtname)+1));
-	strcpy(retn->dataType, dtname);
-
-	retn->command = (char*)ckalloc((unsigned)(strlen(cmd)+1));
-	strcpy(retn->command, cmd);
+	retn->dataType = strdup(dtname);
+	retn->command = strdup(cmd);
 
 	retn->next = NULL;
 	return retn;
@@ -1648,9 +1634,13 @@ static void
 DestroyTargetHandler(dtHndl)
 	DD_TargetHndl *dtHndl;
 {
-	ckfree(dtHndl->dataType);
-	ckfree(dtHndl->command);
-	ckfree((char*)dtHndl);
+	if (dtHndl->dataType != NULL) {
+		free(dtHndl->dataType);
+	}
+	if (dtHndl->command != NULL) {
+		free(dtHndl->command);
+	}
+	free((char*)dtHndl);
 }
 
 /*
@@ -1673,7 +1663,7 @@ UnregTarget(cdata, eventPtr)
 	if (eventPtr->type == DestroyNotify)
 	{
 		DestroyTargetInfo(ddlist,ddname);
-		ckfree((char*)ddentry);
+		free((char*)ddentry);
 	}
 }
 
@@ -1705,7 +1695,7 @@ DragDropSend(dsPtr)
 
 		sprintf(buffer, "%d %d", dsPtr->tokenx, dsPtr->tokeny);
 		status = Tcl_VarEval(ddlist->interp,
-			"send {",target->ddinterp,"} ",DragDropCmdName," location ",buffer,
+			"send {",target->ddinterp,"} ", DRAGDROP_COMMAND," location ",buffer,
 			(char*)NULL);
 
 		if (status == TCL_OK)
@@ -1777,13 +1767,11 @@ DragDropSendHndlr(dsPtr,interpName,ddName)
 	 */
 	Tcl_ResetResult(interp); /* for Tcl_AppendResult() below */
 	if (Tcl_VarEval(interp,
-		"send {",interpName,"} ",DragDropCmdName," target {",ddName,"} handler",
+		"send {",interpName,"} ", DRAGDROP_COMMAND," target {",ddName,"} handler",
 		(char*)NULL) != TCL_OK)
 		return NULL;
 
-	hlist = (char*)ckalloc((unsigned)(strlen(interp->result)+1));
-	strcpy(hlist, interp->result);
-
+	hlist = strdup(interp->result);
 	if (Tcl_SplitList(interp, hlist, &hndlc, &hndlv) == TCL_OK)
 	{
 		/*
@@ -1821,7 +1809,7 @@ DragDropSendHndlr(dsPtr,interpName,ddName)
 							}
 						}
 
-				ckfree((char*)elemv);
+				free((char*)elemv);
 			}
 			else
 			{
@@ -1832,9 +1820,9 @@ DragDropSendHndlr(dsPtr,interpName,ddName)
 				Tk_BackgroundError(interp);
 			}
 		}
-		ckfree((char*)hndlv);
+		free((char*)hndlv);
 	}
-	ckfree(hlist);
+	free(hlist);
 
 	return retn;
 }
@@ -1998,7 +1986,7 @@ WinRepAlloc(ddlist)
 	 */
 	if (!ddlist->pool)
 	{
-		wr = (DD_WinRep*)ckalloc(sizeof(DD_WinRep));
+		wr = (DD_WinRep*)malloc(sizeof(DD_WinRep));
 		wr->next = NULL;
 		ddlist->pool = wr;
 	}
@@ -2122,7 +2110,9 @@ WinRepInit(wr,dsPtr)
 		    (actualFormat != 8) ||
 		    (actualType != XA_STRING))
 		{
-			XFree((caddr_t)propInfo);
+			if (propInfo != NULL) {
+				XFree((caddr_t)propInfo);
+			}
 			propInfo = NULL;
 		}
 
@@ -2183,7 +2173,9 @@ WinRepInit(wr,dsPtr)
 
 				wrtail = wrkid;
 			}
-			XFree((caddr_t)kids);   /* done with list of kids */
+			if (kids != NULL) {
+				XFree((caddr_t)kids);   /* done with list of kids */
+			}
 		}
 	}
 	wr->initialized = ~0;
@@ -2224,7 +2216,7 @@ AddDDProp(dtPtr)
 		for (thandl=dtPtr->handlers; thandl; thandl=thandl->next)
 			Tcl_AppendResult(interp, thandl->dataType, " ", (char*)NULL);
 
-		ddProperty = XInternAtom(dtPtr->display, DragDropInfo, False);
+		ddProperty = XInternAtom(dtPtr->display, DRAGDROP_PROPINFO, False);
 		info = interp->result;
 
 		XChangeProperty(dtPtr->display, Tk_WindowId(dtPtr->tkwin),
@@ -2317,9 +2309,11 @@ MoveDDToken(dsPtr)
 		x -= Tk_Width(tokenwin);
 		break;
 	}
-	x = (x > max) ? max : x;
-	x = (x < 0)   ? 0   : x;
-
+	if (x > max) {
+		x = max;
+	} else if (x < 0) {
+		x = 0;
+	}
 	max = HeightOfScreen(Tk_Screen(dsPtr->tkwin)) - Tk_Height(tokenwin);
 	switch (dsPtr->tokenAnchor)
 	{
@@ -2340,9 +2334,11 @@ MoveDDToken(dsPtr)
 		y -= Tk_Height(tokenwin);
 		break;
 	}
-	y = (y > max) ? max : y;
-	y = (y < 0)   ? 0   : y;
-
+	if (y > max) {
+		y = max;
+	} else if (y < 0) {
+		y = 0;
+	}
 	if ((x != Tk_X(tokenwin)) || (y != Tk_Y(tokenwin)))
 		Tk_MoveWindow(tokenwin, x, y);
 }
@@ -2386,9 +2382,9 @@ UpdateDDToken(clientData)
 		 */
 		if (dsPtr->sitecmd)
 		{
-			char buffer[64];
-			sprintf(buffer, "%d", status);
+			char buffer[200];
 
+			sprintf(buffer, "%d", status);
 			if ((Tcl_VarEval(dsPtr->ddlist->interp,
 					dsPtr->sitecmd," ",buffer," ",Tk_PathName(dsPtr->tokenwin),
 					(char*)NULL) != TCL_OK) &&
@@ -2514,7 +2510,7 @@ StackDelete(stack)
 	DD_Stack *stack;     /* stack to be deleted */
 {
 	if (stack->values != stack->space)  /* allocated extra memory? */
-		ckfree((char*)stack->values);   /* then free it */
+		free((char*)stack->values);   /* then free it */
 
 	stack->values = NULL;
 	stack->len = stack->max = 0;
@@ -2538,15 +2534,15 @@ StackPush(cdata,stack)
 	{
 		stack->max = (stack->max == 0) ? 5 : 2*stack->max;
 		newStack = (ClientData*)
-			ckalloc((unsigned)(stack->max*sizeof(ClientData)));
+			malloc((unsigned)(stack->max*sizeof(ClientData)));
 
 		if (stack->values)
 		{
-			memcpy((char*)newStack, (char*)stack->values,
+			memcpy((char *)newStack, (char *)stack->values,
 				stack->len*sizeof(ClientData));
 
 			if (stack->values != stack->space)
-				ckfree((char*)stack->values);
+				free((char*)stack->values);
 		}
 		stack->values = newStack;
 	}
@@ -2564,7 +2560,8 @@ static ClientData
 StackPop(stack)
 	DD_Stack *stack;  /* stack to be manipulated */
 {
-	return (stack->values && (stack->len > 0))
-		? stack->values[--stack->len]
-		: (ClientData)NULL;
+	if ((stack->values != NULL) && (stack->len > 0)) {
+		return (stack->values[--stack->len]);
+	}
+	return (ClientData) 0;
 }
