@@ -123,7 +123,9 @@ typedef struct {
  */
 
 typedef struct {
-    unsigned int flags;
+    enum AxisTypes type;	/* Type of axis: X1, Y1, X2, or Y2 */
+    enum AxisLocations location;/* Location of the axis relative to plotting
+				 * surface: right, left, etc. */
     int logScale;		/* If non-zero, scale values logarithmically */
     int mapped;			/* If non-zero, display the axis */
 
@@ -137,6 +139,8 @@ typedef struct {
     int showTicks;		/* If non-zero, display (both major
 				 * and minor) ticks on the axis */
     int loose;			/* If non-zero, autoscale limits loosely */
+    int descending;		/* In non-zero, axis values are descending
+				 * instead of monotonically increasing. */
     Tk_Anchor anchor;		/* Anchor of tick labels */
     double limits[2];		/* Limits for scaling of axis */
     double prevMin, prevMax;	/* Last limits for scaling of axis */
@@ -164,6 +168,7 @@ typedef struct {
 				 * Calculated by tick layout routines. */
 
     /* Calculated values */
+    unsigned int flags;
     int baseline;		/* Screen location of baseline */
     int majorTick;		/* Screen location of major tick */
     int minorTick;		/* Screen location of minor tick */
@@ -171,7 +176,6 @@ typedef struct {
     int titleX, titleY;		/* Coordinates of axis title */
 
     Tcl_Interp *interp;
-    enum AxisTypes type;	/* Type of axis */
     unsigned int width, height;	/* Bounding box of axis */
 
     double tickMin, tickMax;	/* Smallest and largest possible major
@@ -203,11 +207,9 @@ typedef struct {
 				 * the background color of the graph
 				 * changes. */
 
-
 } Axis;
 
 /* Axis flags: */
-/* bits 0-3 contain the axis type information */
 #define AXIS_CONFIG_DIRTY	(1<<8)
 #define AXIS_CONFIG_USER_BIT	(1<<9)
 #define AXIS_CONFIG_MIN_MASK	(AXIS_CONFIG_USER_BIT << LMIN)
@@ -215,15 +217,19 @@ typedef struct {
 #define AXIS_CONFIG_MIN_SET(a) 	((a)->flags & AXIS_CONFIG_MIN_MASK)
 #define AXIS_CONFIG_MAX_SET(a) 	((a)->flags & AXIS_CONFIG_MAX_MASK)
 
+#define VERTICAL_AXIS(a)	((a)->location&1)
+#define HORIZONTAL_AXIS(a)    	(!((a)->location&1))
+
 #define DEF_AXIS_FG_COLOR	BLACK
 #define DEF_AXIS_FG_MONO	BLACK
 #define DEF_AXIS_FONT	 	"*-Courier-Bold-R-Normal-*-100-*"
 #define DEF_AXIS_TICKS		"1"
-#define DEF_AXIS_SUBTICKS_GRAPH		"2"
+#define DEF_AXIS_SUBTICKS_GRAPH	"2"
 #define DEF_AXIS_X_SUBTICKS_BARCHART	"0"
 #define DEF_AXIS_X_STEPSIZE_BARCHART	"1.0"
 #define DEF_AXIS_ALT_MAPPED 	"false"
 #define DEF_AXIS_STD_MAPPED 	"true"
+#define DEF_AXIS_DESCENDING 	"false"
 
 static Tk_ConfigSpec xAxisConfigSpecs[] =
 {
@@ -234,7 +240,11 @@ static Tk_ConfigSpec xAxisConfigSpecs[] =
 	DEF_AXIS_FG_MONO, Tk_Offset(Axis, fgColorPtr),
 	TK_CONFIG_MONO_ONLY | ALL_MASK},
     {TK_CONFIG_STRING, "-command", "xCommand", "AxisCommand",
-	(char *)NULL, Tk_Offset(Axis, formatCmd), ALL_MASK | TK_CONFIG_NULL_OK},
+	(char *)NULL, Tk_Offset(Axis, formatCmd),
+	ALL_MASK | TK_CONFIG_NULL_OK},
+    {TK_CONFIG_BOOLEAN, "-descending", "xDescending", "AxisDescending",
+	DEF_AXIS_DESCENDING, Tk_Offset(Axis, descending),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_FONT, "-font", "xFont", "AxisFont",
 	DEF_AXIS_FONT, Tk_Offset(Axis, fontPtr), ALL_MASK},
     {TK_CONFIG_PIXELS, "-linewidth", "xLinewidth", "AxisLinewidth",
@@ -270,6 +280,7 @@ static Tk_ConfigSpec xAxisConfigSpecs[] =
     {TK_CONFIG_END, NULL, NULL, NULL, NULL, 0, 0}
 };
 
+
 static Tk_ConfigSpec x2AxisConfigSpecs[] =
 {
     {TK_CONFIG_COLOR, "-color", "x2Color", "AxisColor",
@@ -279,7 +290,11 @@ static Tk_ConfigSpec x2AxisConfigSpecs[] =
 	DEF_AXIS_FG_MONO, Tk_Offset(Axis, fgColorPtr),
 	TK_CONFIG_MONO_ONLY | ALL_MASK},
     {TK_CONFIG_STRING, "-command", "x2Command", "AxisCommand",
-	(char *)NULL, Tk_Offset(Axis, formatCmd), ALL_MASK | TK_CONFIG_NULL_OK},
+	(char *)NULL, Tk_Offset(Axis, formatCmd),
+	ALL_MASK | TK_CONFIG_NULL_OK},
+    {TK_CONFIG_BOOLEAN, "-descending", "x2Descending", "AxisDescending",
+	DEF_AXIS_DESCENDING, Tk_Offset(Axis, descending),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_FONT, "-font", "x2Font", "AxisFont",
 	DEF_AXIS_FONT, Tk_Offset(Axis, fontPtr), ALL_MASK},
     {TK_CONFIG_PIXELS, "-linewidth", "x2Linewidth", "AxisLinewidth",
@@ -317,7 +332,11 @@ static Tk_ConfigSpec yAxisConfigSpecs[] =
 	DEF_AXIS_FG_MONO, Tk_Offset(Axis, fgColorPtr),
 	TK_CONFIG_MONO_ONLY | ALL_MASK},
     {TK_CONFIG_STRING, "-command", "yCommand", "AxisCommand",
-	(char *)NULL, Tk_Offset(Axis, formatCmd), ALL_MASK | TK_CONFIG_NULL_OK},
+	(char *)NULL, Tk_Offset(Axis, formatCmd),
+	ALL_MASK | TK_CONFIG_NULL_OK},
+    {TK_CONFIG_BOOLEAN, "-descending", "yDescending", "AxisDescending",
+	DEF_AXIS_DESCENDING, Tk_Offset(Axis, descending),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_FONT, "-font", "yFont", "AxisFont",
 	DEF_AXIS_FONT, Tk_Offset(Axis, fontPtr), ALL_MASK},
     {TK_CONFIG_BOOLEAN, "-loose", "yLoose", "AxisLoose",
@@ -357,6 +376,9 @@ static Tk_ConfigSpec y2AxisConfigSpecs[] =
     {TK_CONFIG_STRING, "-command", "y2Command", "AxisCommand",
 	(char *)NULL, Tk_Offset(Axis, formatCmd),
 	ALL_MASK | TK_CONFIG_NULL_OK},
+    {TK_CONFIG_BOOLEAN, "-descending", "y2Descending", "AxisDescending",
+	DEF_AXIS_DESCENDING, Tk_Offset(Axis, descending),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_FONT, "-font", "y2Font", "AxisFont",
 	DEF_AXIS_FONT, Tk_Offset(Axis, fontPtr), ALL_MASK},
     {TK_CONFIG_BOOLEAN, "-loose", "y2Loose", "AxisLoose",
@@ -603,15 +625,19 @@ Blt_InvTransform(axis, coord)
     GraphAxis *axis;
     int coord;
 {
-    double value;
+    double norm, value;
     Axis *axisPtr = (Axis *)axis;
 
-    if (axisPtr->flags & AXIS_X_MASK) {
-	value = coord - axisPtr->offset;
+    if (HORIZONTAL_AXIS(axisPtr)) {
+	coord = (coord - axisPtr->offset);
     } else {
-	value = axisPtr->offset - coord;
+	coord = (axisPtr->offset - coord);
     }
-    value = ((value / axisPtr->scale) * axisPtr->range) + axisPtr->min;
+    norm = ((double)coord / axisPtr->scale);
+    if (axisPtr->descending) {
+	norm = 1.0 - norm;
+    }
+    value = (norm * axisPtr->range) + axisPtr->min;
     if (axisPtr->logScale) {
 	value = EXP10(value);
     }
@@ -646,11 +672,12 @@ Blt_Transform(axis, value)
     int coord;
 
     norm = Scale(axisPtr, value);
-    if (axisPtr->flags & AXIS_X_MASK) {
-	coord = MAPX(axisPtr, norm);
-    } else {
-	coord = MAPY(axisPtr, norm);
+    if (axisPtr->descending) {
+	norm = 1.0 - norm;
     }
+    coord = HORIZONTAL_AXIS(axisPtr)
+	? MAPX(axisPtr, norm) : MAPY(axisPtr, norm);
+
     /* Should really figure out a good offset value and test for that
      * because we could still generate bogus numbers */
     if (coord >= SHRT_MAX) {
@@ -675,20 +702,25 @@ Blt_Transform(axis, value)
  * ----------------------------------------------------------------------
  */
 XPoint
-Blt_TransformPt(graphPtr, x, y, flags)
+Blt_TransformPt(graphPtr, x, y, axisFlags)
     Graph *graphPtr;
     double x, y;
-    unsigned int flags;		/* Specifies which axis to use */
+    unsigned int axisFlags;	/* Specifies which axes to use */
 {
     XPoint winPos;
-    GraphAxis *axis;
+    enum AxisTypes axisType;
 
-    axis = (flags & AXIS_X1_FLAG)
-	? graphPtr->axisArr[X1] : graphPtr->axisArr[X2];
-    winPos.x = Blt_Transform(axis, x);
-    axis = (flags & AXIS_Y1_FLAG)
-	? graphPtr->axisArr[Y1] : graphPtr->axisArr[Y2];
-    winPos.y = Blt_Transform(axis, y);
+    axisType = (axisFlags & X1_AXIS_MASK) ? X1_AXIS : X1_AXIS;
+    winPos.x = Blt_Transform(graphPtr->axisArr[axisType], x);
+    axisType = (axisFlags & Y1_AXIS_MASK) ? Y1_AXIS : Y2_AXIS;
+    winPos.y = Blt_Transform(graphPtr->axisArr[axisType], y);
+    if (graphPtr->inverted) {	/* Swap x and y coordinates */
+	int coord;
+
+	coord = winPos.y;
+	winPos.y = winPos.x;
+	winPos.x = coord;
+    }
     return (winPos);
 }
 
@@ -720,12 +752,13 @@ Blt_TransformDist(axis, value)
     int zero, coord;
 
     norm = Scale(axisPtr, 0.0);
-    zero = (axisPtr->flags & AXIS_X_MASK)
+    zero = HORIZONTAL_AXIS(axisPtr)
 	? MAPX(axisPtr, norm) : MAPY(axisPtr, norm);
     norm = Scale(axisPtr, value);
-    coord = (axisPtr->flags & AXIS_X_MASK)
+    coord = HORIZONTAL_AXIS(axisPtr)
 	? MAPX(axisPtr, norm) : MAPY(axisPtr, norm);
-    return (coord - zero);
+    coord -= zero;
+    return (ABS(coord));
 }
 
 /*
@@ -747,24 +780,26 @@ Blt_PointOnGraph(graphPtr, pointPtr)
     Graph *graphPtr;
     XPoint *pointPtr;
 {
-    double normX, normY;
+    double norm;
     Axis *axisPtr;
 
     /*
-     * It doesn't make a difference which x-axis or y-axis we use
-     * since the point is referenced by window coordinates.
+     * It doesn't make a difference which x-axis or y-axis we use 
+     * (the point is referenced by window coordinates). We're just 
+     * checking if the point's within the range of axis' normalized 
+     * coordinates [0..1].
      */
-    axisPtr = (Axis *)graphPtr->axisArr[X1];
+    axisPtr = (Axis *)graphPtr->bottomAxis;
     if (axisPtr->scale == 0.0) {
 	return 0;		/* Axis layout hasn't been calculated yet */
     }
-    normX = (pointPtr->x - axisPtr->offset) / axisPtr->scale;
-    if ((normX < 0.0) || (normX > 1.0)) {
+    norm = (pointPtr->x - axisPtr->offset) / axisPtr->scale;
+    if ((norm < 0.0) || (norm > 1.0)) {
 	return 0;		/* x-coordinates are off the graph */
     }
-    axisPtr = (Axis *)graphPtr->axisArr[Y1];
-    normY = (axisPtr->offset - pointPtr->y) / axisPtr->scale;
-    return ((normY >= 0.0) && (normY <= 1.0));
+    axisPtr = (Axis *)graphPtr->leftAxis;
+    norm = (axisPtr->offset - pointPtr->y) / axisPtr->scale;
+    return ((norm >= 0.0) && (norm <= 1.0));
 }
 
 /*
@@ -785,9 +820,9 @@ Blt_PointOnGraph(graphPtr, pointPtr)
  * ----------------------------------------------------------------------
  */
 static void
-UpdateLimits(axisPtr, listPtr)
+UpdateLimits(graphPtr, axisPtr)
+    Graph *graphPtr;
     Axis *axisPtr;
-    Blt_LinkedList *listPtr;
 {
     int result;
 
@@ -801,11 +836,11 @@ UpdateLimits(axisPtr, listPtr)
 	/* Find the minimum and maximum values for all the elements
 	   displayed */
 	min = Blt_posInfinity, max = Blt_negInfinity;
-	for (entryPtr = Blt_FirstListEntry(listPtr); entryPtr != NULL;
-	    entryPtr = Blt_NextListEntry(entryPtr)) {
+	for (entryPtr = Blt_FirstListEntry(&(graphPtr->elemList));
+	    entryPtr != NULL; entryPtr = Blt_NextListEntry(entryPtr)) {
 	    elemPtr = (Element *)Blt_GetListValue(entryPtr);
-	    if ((*elemPtr->limitsProc) (elemPtr, (GraphAxis *)axisPtr,
-		    &elemMin, &elemMax) > 0) {
+	    if ((*elemPtr->limitsProc) (graphPtr, elemPtr,
+		    (GraphAxis *)axisPtr, &elemMin, &elemMax) > 0) {
 		if (min > elemMin) {
 		    min = elemMin;
 		}
@@ -1206,9 +1241,13 @@ SetAxisLimits(graphPtr, axisPtr)
     Graph *graphPtr;
     Axis *axisPtr;
 {
-    /* For barcharts, adjust the minimum or maximum values to include 0.0. */
+    UpdateLimits(graphPtr, axisPtr);
 
-    if ((axisPtr->flags & AXIS_Y_MASK) && (graphPtr->type == BARCHART)) {
+    /*
+     * For barcharts, adjust the min or max values to include 0.0
+     * if the bars are drawn along this axis.
+     */
+    if ((graphPtr->type == BARCHART) && (Y_AXIS(axisPtr))) {
 	if (!AXIS_CONFIG_MIN_SET(axisPtr) && (axisPtr->limits[LMIN] > 0.0)) {
 	    axisPtr->limits[LMIN] = 0.0;
 	}
@@ -1216,8 +1255,6 @@ SetAxisLimits(graphPtr, axisPtr)
 	    axisPtr->limits[LMAX] = 0.0;
 	}
     }
-    UpdateLimits(axisPtr, &(graphPtr->elemList));
-
     if (axisPtr->flags & AXIS_CONFIG_DIRTY) {
 	/* Calculate min/max tick (major/minor) layouts */
 	if (axisPtr->logScale) {
@@ -1429,7 +1466,7 @@ CalculateOffsets(graphPtr, axisPtr)
     int halfLW;
     int textHeight;
     int titleOffset;
-    Axis *oppAxis;		/* Opposing axis */
+    Axis *oppPtr;		/* Opposite axis */
     int x2Offset;
 
     /* Adjust offset for the interior border width and the line width */
@@ -1445,53 +1482,59 @@ CalculateOffsets(graphPtr, axisPtr)
      * Pre-calculate the x-coordinate positions of the baseline,
      * tick labels, and the individual major and minor ticks.
      */
-    if (axisPtr->flags & AXIS_X_MASK) {
-	oppAxis = (Axis *)graphPtr->axisArr[Y1];
+    if (HORIZONTAL_AXIS(axisPtr)) {
+	oppPtr = (Axis *)graphPtr->leftAxis;
     } else {
-	oppAxis = (Axis *)graphPtr->axisArr[X1];
+	oppPtr = (Axis *)graphPtr->bottomAxis;
     }
 
-    switch (axisPtr->type) {
-    case X1:
-	axisPtr->majorTick = MAPY(oppAxis, -MAJOR_TICK) + pad + halfLW;
-	axisPtr->minorTick = MAPY(oppAxis, -MINOR_TICK) + pad + halfLW;
+    switch (axisPtr->location) {
+    case BOTTOM_AXIS:
+	axisPtr->majorTick = MAPY(oppPtr, -MAJOR_TICK) + pad + halfLW;
+	axisPtr->minorTick = MAPY(oppPtr, -MINOR_TICK) + pad + halfLW;
 	axisPtr->baseline = graphPtr->origin.y + pad;
-	axisPtr->tickLabel = MAPY(oppAxis, -LABEL_TICK) +
+	axisPtr->tickLabel = MAPY(oppPtr, -LABEL_TICK) +
 	    (axisPtr->lineWidth + graphPtr->intBWidth + pad);
 	axisPtr->titleX = (graphPtr->extreme.x + graphPtr->origin.x) / 2;
 	axisPtr->titleY = graphPtr->height - titleOffset;
+	axisPtr->anchor = TK_ANCHOR_N;
 	break;
 
-    case Y1:
-	axisPtr->majorTick = MAPX(oppAxis, -MAJOR_TICK) - (pad + halfLW);
-	axisPtr->minorTick = MAPX(oppAxis, -MINOR_TICK) - (pad + halfLW);
+    case LEFT_AXIS:
+	axisPtr->majorTick = MAPX(oppPtr, -MAJOR_TICK) - (pad + halfLW);
+	axisPtr->minorTick = MAPX(oppPtr, -MINOR_TICK) - (pad + halfLW);
 	axisPtr->baseline = graphPtr->origin.x - pad;
-	axisPtr->tickLabel = MAPX(oppAxis, -LABEL_TICK) -
+	axisPtr->tickLabel = MAPX(oppPtr, -LABEL_TICK) -
 	    (axisPtr->lineWidth + graphPtr->intBWidth + pad);
 	axisPtr->titleX = titleOffset;
 	axisPtr->titleY = (graphPtr->origin.y + graphPtr->extreme.y) / 2;
+	axisPtr->anchor = TK_ANCHOR_E;
 	break;
 
-    case X2:
-	axisPtr->majorTick = MAPY(oppAxis, 1.0 + MAJOR_TICK) - (pad + halfLW);
-	axisPtr->minorTick = MAPY(oppAxis, 1.0 + MINOR_TICK) - (pad + halfLW);
+    case TOP_AXIS:
+	axisPtr->majorTick =
+	    MAPY(oppPtr, 1.0 + MAJOR_TICK) - (pad + halfLW);
+	axisPtr->minorTick =
+	    MAPY(oppPtr, 1.0 + MINOR_TICK) - (pad + halfLW);
 	axisPtr->baseline = graphPtr->extreme.y - pad;
-	axisPtr->tickLabel = MAPY(oppAxis, 1.0 + LABEL_TICK) -
+	axisPtr->tickLabel = MAPY(oppPtr, 1.0 + LABEL_TICK) -
 	    (axisPtr->lineWidth + graphPtr->intBWidth + pad);
 	axisPtr->titleX = (graphPtr->extreme.x + graphPtr->origin.x) / 2;
 	x2Offset = (graphPtr->title != NULL) ? 2 * textHeight : textHeight / 2;
 	axisPtr->titleY = titleOffset + x2Offset;
+	axisPtr->anchor = TK_ANCHOR_S;
 	break;
 
-    case Y2:
-	axisPtr->majorTick = MAPX(oppAxis, 1.0 + MAJOR_TICK) + pad + halfLW;
-	axisPtr->minorTick = MAPX(oppAxis, 1.0 + MINOR_TICK) + pad + halfLW;
+    case RIGHT_AXIS:
+	axisPtr->majorTick = MAPX(oppPtr, 1.0 + MAJOR_TICK) + pad + halfLW;
+	axisPtr->minorTick = MAPX(oppPtr, 1.0 + MINOR_TICK) + pad + halfLW;
 	axisPtr->baseline = graphPtr->extreme.x + pad;
-	axisPtr->tickLabel = MAPX(oppAxis, 1.0 + LABEL_TICK) +
+	axisPtr->tickLabel = MAPX(oppPtr, 1.0 + LABEL_TICK) +
 	    (axisPtr->lineWidth + graphPtr->intBWidth + pad);
 	axisPtr->titleX = graphPtr->width -
 	    (graphPtr->legendPtr->width + titleOffset);
 	axisPtr->titleY = (graphPtr->origin.y + graphPtr->extreme.y) / 2;
+	axisPtr->anchor = TK_ANCHOR_W;
 	break;
 
     }
@@ -1502,21 +1545,25 @@ Baseline(axisPtr, min, max)
     Axis *axisPtr;		/* Axis information */
     double min, max;		/* Limits of baseline in graph coordinates */
 {
-    double norm;
+    double normMin, normMax;
     XSegment segment;
 
-    if (axisPtr->flags & AXIS_X_MASK) {
+    normMax = NORM(axisPtr, min);
+    if (axisPtr->descending) {
+	normMax = 1.0 - normMax;
+    }
+    normMin = NORM(axisPtr, max);
+    if (axisPtr->descending) {
+	normMin = 1.0 - normMin;
+    }
+    if (HORIZONTAL_AXIS(axisPtr)) {
 	segment.y1 = segment.y2 = axisPtr->baseline;
-	norm = NORM(axisPtr, min);
-	segment.x1 = MAPX(axisPtr, norm);
-	norm = NORM(axisPtr, max);
-	segment.x2 = MAPX(axisPtr, norm);
+	segment.x1 = MAPX(axisPtr, normMin);
+	segment.x2 = MAPX(axisPtr, normMax);
     } else {
 	segment.x1 = segment.x2 = axisPtr->baseline;
-	norm = NORM(axisPtr, min);
-	segment.y1 = MAPY(axisPtr, norm);
-	norm = NORM(axisPtr, max);
-	segment.y2 = MAPY(axisPtr, norm);
+	segment.y1 = MAPY(axisPtr, normMin);
+	segment.y2 = MAPY(axisPtr, normMax);
     }
     return (segment);
 }
@@ -1533,8 +1580,11 @@ Tick(axisPtr, value, flag)
     int tick;
 
     norm = NORM(axisPtr, value);
+    if (axisPtr->descending) {
+	norm = 1.0 - norm;
+    }
     tick = (flag) ? axisPtr->minorTick : axisPtr->majorTick;
-    if (axisPtr->flags & AXIS_X_MASK) {
+    if (HORIZONTAL_AXIS(axisPtr)) {
 	segment.y1 = axisPtr->baseline;
 	segment.y2 = tick;
 	segment.x1 = segment.x2 = MAPX(axisPtr, norm);
@@ -1637,7 +1687,7 @@ LayoutAxis(graphPtr, axis)
 	    segArr[sgmts] = Tick(axisPtr, value, 0);
 
 	    /* Save tick label position */
-	    if (axisPtr->flags & AXIS_X_MASK) {
+	    if (HORIZONTAL_AXIS(axisPtr)) {
 		axisPtr->labelArr[labels].x = segArr[sgmts].x1;
 		axisPtr->labelArr[labels].y = (short int)axisPtr->tickLabel;
 	    } else {
@@ -1700,7 +1750,7 @@ DisplayAxis(graphPtr, axis, attrPtr)
     Axis *axisPtr = (Axis *)axis;
 
     if (axisPtr->title != NULL) {
-	attrPtr->theta = (double)titleRot[axisPtr->type];
+	attrPtr->theta = (double)titleRot[axisPtr->location];
 	Blt_DrawText(graphPtr->display, graphPtr->canvas, axisPtr->title,
 	    attrPtr, axisPtr->titleX, axisPtr->titleY);
     }
@@ -1758,7 +1808,7 @@ PrintAxis(graphPtr, axis, attrPtr)
     Axis *axisPtr = (Axis *)axis;
 
     if (axisPtr->title != NULL) {
-	attrPtr->theta = (double)titleRot[axisPtr->type];
+	attrPtr->theta = (double)titleRot[axisPtr->location];
 	Blt_TextToPostScript(graphPtr, axisPtr->title, attrPtr,
 	    axisPtr->titleX, axisPtr->titleY);
     }
@@ -1963,10 +2013,10 @@ Blt_ComputeLayout(graphPtr)
     int halfHeight = (lineHeight / 2);
     double normYScale, normXScale;
 
-    x1 = (Axis *)graphPtr->axisArr[X1];
-    x2 = (Axis *)graphPtr->axisArr[X2];
-    y1 = (Axis *)graphPtr->axisArr[Y1];
-    y2 = (Axis *)graphPtr->axisArr[Y2];
+    x1 = (Axis *)graphPtr->bottomAxis;
+    x2 = (Axis *)graphPtr->topAxis;
+    y1 = (Axis *)graphPtr->leftAxis;
+    y2 = (Axis *)graphPtr->rightAxis;
 
     top = (graphPtr->title != NULL) ? twiceHeight : halfHeight;
     left = ((y1->mapped) && (y1->title != NULL)) ? twiceHeight : halfHeight;
@@ -2124,8 +2174,7 @@ InvTransformCoord(axisPtr, argc, argv)
     if (argc != 4) {
 	Tcl_AppendResult(axisPtr->interp, "wrong # args: should be \"",
 	    argv[0], " ", axisNames[axisPtr->type],
-	    "axis invtransform winPos\"",
-	    (char *)NULL);
+	    "axis invtransform winPos\"", (char *)NULL);
 	return TCL_ERROR;
     }
     if (Tcl_GetInt(axisPtr->interp, argv[2], &coord) != TCL_OK) {
@@ -2195,13 +2244,17 @@ Blt_CreateAxis(graphPtr, type, flags)
     int flags;			/* Configuration flags */
 {
     Axis *axisPtr;
+    enum AxisLocations location;
 
     axisPtr = (Axis *)calloc(1, sizeof(Axis));
     if (axisPtr == NULL) {
 	graphPtr->interp->result = "can't allocate axis structure";
 	return TCL_ERROR;
     }
+    location = (AxisLocation) type;	/* For now, there's a 1-1 correspondence
+				    * between axis types and locations */
     axisPtr->type = type;
+    axisPtr->location = location;
     axisPtr->interp = graphPtr->interp;	/* Needed for Tcl_PrintDouble */
     axisPtr->flags = 0;
     axisPtr->step = 1.0;
@@ -2210,31 +2263,8 @@ Blt_CreateAxis(graphPtr, type, flags)
     axisPtr->displayProc = DisplayAxis;
     axisPtr->layoutProc = LayoutAxis;
     axisPtr->printProc = PrintAxis;
-    axisPtr->mapped = 1;
-    axisPtr->flags = (1 << type);
-    switch (type) {
-    case X1:
-	axisPtr->anchor = TK_ANCHOR_N;
-	break;
+    axisPtr->mapped = ((location == BOTTOM_AXIS) || (location == LEFT_AXIS));
 
-    case X2:
-	axisPtr->mapped = 0;	/* By default, don't map alternate x-axis */
-	axisPtr->anchor = TK_ANCHOR_S;
-	break;
-
-    case Y1:
-	axisPtr->anchor = TK_ANCHOR_E;
-	break;
-
-    case Y2:
-	axisPtr->mapped = 0;	/* By default, don't map alternate y-axis */
-	axisPtr->anchor = TK_ANCHOR_W;
-	break;
-
-    default:
-	graphPtr->interp->result = "internal error: wrong axis type";
-	return TCL_ERROR;
-    }
     graphPtr->axisArr[type] = (GraphAxis *)axisPtr;
     if (ConfigureAxis(graphPtr, axisPtr, 0, (char **)NULL, flags) != TCL_OK) {
 	return TCL_ERROR;
