@@ -63,8 +63,8 @@ typedef void (ElemDestroyProc) _ANSI_ARGS_((Graph *, Element *));
 typedef int (ElemConfigProc) _ANSI_ARGS_((Graph *, Element *));
 typedef void (ElemLayoutProc) _ANSI_ARGS_((Graph *, Element *));
 typedef void (ElemPrintProc) _ANSI_ARGS_((Graph *, Element *));
-typedef int (ElemLimitsProc) _ANSI_ARGS_((Element *, GraphAxis *, double *,
-	double *));
+typedef int (ElemLimitsProc) _ANSI_ARGS_((Graph *, Element *, GraphAxis *, 
+	double *, double *));
 typedef double (ElemDistanceProc) _ANSI_ARGS_((Graph *, Element *, int, int,
 	int *));
 typedef void (ElemDrawSymbolsProc) _ANSI_ARGS_((Graph *, Element *, int,
