@@ -1,3 +1,4 @@
+
 /*
  * bltGrMisc.c --
  *
@@ -161,15 +162,15 @@ Blt_ParseAxisFlags(clientData, interp, tkwin, value, widgRec, offset)
     int flags;
 
     flags = 0;
-    if (mask == AXIS_X_MASK) {
+    if (mask == ANY_X_MASK) {
 	if (strcmp(value, "x2") == 0) {
-	    flags = AXIS_X2_FLAG;
+	    flags = X2_AXIS_MASK;
 	} else if (strcmp(value, "x1") == 0) {
-	    flags = AXIS_X1_FLAG;
+	    flags = X1_AXIS_MASK;
 	} else if (strcmp(value, "x") == 0) {
-	    flags = AXIS_X1_FLAG;
+	    flags = X1_AXIS_MASK;
 	} else if (strcmp(value, "both") == 0) {
-	    flags = (AXIS_X1_FLAG | AXIS_X2_FLAG);
+	    flags = (X1_AXIS_MASK | X2_AXIS_MASK);
 	} else {
 	    Tcl_AppendResult(interp, "bad x-axis type \"", value,
 		"\": should be x or x2", (char *)NULL);
@@ -177,13 +178,13 @@ Blt_ParseAxisFlags(clientData, interp, tkwin, value, widgRec, offset)
 	}
     } else {
 	if (strcmp(value, "y2") == 0) {
-	    flags = AXIS_Y2_FLAG;
+	    flags = Y2_AXIS_MASK;
 	} else if (strcmp(value, "y1") == 0) {
-	    flags = AXIS_Y1_FLAG;
+	    flags = Y1_AXIS_MASK;
 	} else if (strcmp(value, "y") == 0) {
-	    flags = AXIS_Y1_FLAG;
+	    flags = Y1_AXIS_MASK;
 	} else if (strcmp(value, "both") == 0) {
-	    flags = (AXIS_Y1_FLAG | AXIS_Y2_FLAG);
+	    flags = (Y1_AXIS_MASK | Y2_AXIS_MASK);
 	} else {
 	    Tcl_AppendResult(interp, "bad y-axis type \"", value,
 		"\": should be y or y2", (char *)NULL);
@@ -222,15 +223,15 @@ Blt_PrintAxisFlags(clientData, tkwin, widgRec, offset, freeProcPtr)
 
     flags &= mask;
     result = "";
-    if ((flags == AXIS_X_MASK) || (flags == AXIS_Y_MASK)) {
+    if ((flags == ANY_X_MASK) || (flags == ANY_Y_MASK)) {
 	result = "both";
-    } else if (flags & AXIS_X1_FLAG) {
+    } else if (flags & X1_AXIS_MASK) {
 	result = "x";
-    } else if (flags & AXIS_X2_FLAG) {
+    } else if (flags & X2_AXIS_MASK) {
 	result = "x2";
-    } else if (flags & AXIS_Y1_FLAG) {
+    } else if (flags & Y1_AXIS_MASK) {
 	result = "y";
-    } else if (flags & AXIS_Y2_FLAG) {
+    } else if (flags & Y2_AXIS_MASK) {
 	result = "y2";
     }
     return (result);
