@@ -1,3 +1,4 @@
+
 /*
  * bltGrTag.c --
  *
@@ -36,11 +37,11 @@ extern char *Blt_PrintAxisFlags _ANSI_ARGS_((ClientData, Tk_Window, char *, int,
 
 static Tk_CustomOption XAxisFlagsOption =
 {
-    Blt_ParseAxisFlags, Blt_PrintAxisFlags, (ClientData)AXIS_X_MASK
+    Blt_ParseAxisFlags, Blt_PrintAxisFlags, (ClientData)ANY_X_MASK
 };
 static Tk_CustomOption YAxisFlagsOption =
 {
-    Blt_ParseAxisFlags, Blt_PrintAxisFlags, (ClientData)AXIS_Y_MASK
+    Blt_ParseAxisFlags, Blt_PrintAxisFlags, (ClientData)ANY_Y_MASK
 };
 
 #define DEF_TAG_ANCHOR		"center"
@@ -2255,7 +2256,7 @@ CreateTag(graphPtr, argc, argv)
 	return TCL_ERROR;
     }
     tagPtr->type = (TagClassType) type;
-    tagPtr->axisFlags = (AXIS_X1_FLAG | AXIS_Y1_FLAG);
+    tagPtr->axisFlags = STD_AXES_MASK;
     tagPtr->typeProc = TypeOfTag;
     sprintf(tagId, "TAG%d", graphPtr->nextTagId++);
     tagPtr->id = Tk_GetUid(tagId);
