@@ -1,3 +1,4 @@
+
 /*
  * bltGraph.c --
  *
@@ -54,7 +55,7 @@
 #include <X11/Xatom.h>
 
 #ifndef GRAPH_VERSION
-#define GRAPH_VERSION "3.2"
+#define GRAPH_VERSION "3.3"
 #endif
 
 #define TRUE  1
@@ -87,6 +88,7 @@ static unsigned int configFlags[] =
 #define DEF_INT_RELIEF_MONO	"flat"
 #define DEF_INT_BW_MONO       	(char *)NULL
 #define DEF_INT_BW_COLOR      	"2"
+#define DEF_GRAPH_INVERT_XY	"false"
 
 static Tk_ConfigSpec configSpecs[] =
 {
@@ -123,6 +125,9 @@ static Tk_ConfigSpec configSpecs[] =
 	DEF_GRAPH_HALO, Tk_Offset(Graph, halo), XYGRAPH_MASK},
     {TK_CONFIG_PIXELS, "-height", "height", "Height",
 	DEF_GRAPH_HEIGHT, Tk_Offset(Graph, reqHeight), ALL_MASK},
+    {TK_CONFIG_BOOLEAN, "-invertxy", "invertXY", "InvertXY",
+	DEF_GRAPH_INVERT_XY, Tk_Offset(Graph, inverted),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_PIXELS, "-leftmargin", "leftMargin", "Margin",
 	(char *)NULL, Tk_Offset(Graph, leftMargin), ALL_MASK},
     {TK_CONFIG_COLOR, "-plotbackground", "plotBackground", "Background",
@@ -275,7 +280,7 @@ GraphCoords(graphPtr, argc, argv)
 {
     int winX, winY;		/* Integer window coordinates representation */
     char string[TCL_DOUBLE_SPACE + 1];
-    double value;
+    double x, y;
 
     if (argc != 4) {
 	Tcl_AppendResult(graphPtr->interp, "wrong # args: should be \"",
@@ -290,13 +295,20 @@ GraphCoords(graphPtr, argc, argv)
      * Perform the reverse transformation from window coordinates to
      * data coordinates
      */
-    value = Blt_InvTransform(graphPtr->axisArr[X1], winX);
-    Tcl_PrintDouble(graphPtr->interp, value, string);
-    Tcl_AppendElement(graphPtr->interp, string);
+    x = Blt_InvTransform(graphPtr->axisArr[X1_AXIS], winX);
+    y = Blt_InvTransform(graphPtr->axisArr[Y1_AXIS], winY);
 
-    value = Blt_InvTransform(graphPtr->axisArr[Y1], winY);
-    Tcl_PrintDouble(graphPtr->interp, value, string);
-    Tcl_AppendElement(graphPtr->interp, string);
+    if (graphPtr->inverted) {
+	Tcl_PrintDouble(graphPtr->interp, y, string);
+	Tcl_AppendElement(graphPtr->interp, string);
+	Tcl_PrintDouble(graphPtr->interp, x, string);
+	Tcl_AppendElement(graphPtr->interp, string);
+    } else {
+	Tcl_PrintDouble(graphPtr->interp, x, string);
+	Tcl_AppendElement(graphPtr->interp, string);
+	Tcl_PrintDouble(graphPtr->interp, y, string);
+	Tcl_AppendElement(graphPtr->interp, string);
+    }
     return TCL_OK;
 }
 
@@ -324,7 +336,6 @@ WindowCoords(graphPtr, argc, argv)
 {
     double x, y;
     char string[TCL_DOUBLE_SPACE + 1];
-    int winX, winY;
 
     if (argc != 4) {
 	Tcl_AppendResult(graphPtr->interp, "wrong # args: should be \"",
@@ -336,15 +347,54 @@ WindowCoords(graphPtr, argc, argv)
 	return TCL_ERROR;
     }
     /* Perform the transformation from window coordinates to data */
-    winX = Blt_Transform(graphPtr->axisArr[X1], x);
-    sprintf(string, "%d", winX);
-    Tcl_AppendElement(graphPtr->interp, string);
-    winY = Blt_Transform(graphPtr->axisArr[Y1], y);
-    sprintf(string, "%d", winY);
-    Tcl_AppendElement(graphPtr->interp, string);
+    if (graphPtr->inverted) {
+	sprintf(string, "%d", Blt_Transform(graphPtr->axisArr[Y1_AXIS], y));
+	Tcl_AppendElement(graphPtr->interp, string);
+	sprintf(string, "%d", Blt_Transform(graphPtr->axisArr[X1_AXIS], x));
+	Tcl_AppendElement(graphPtr->interp, string);
+    } else {
+	sprintf(string, "%d", Blt_Transform(graphPtr->axisArr[X1_AXIS], x));
+	Tcl_AppendElement(graphPtr->interp, string);
+	sprintf(string, "%d", Blt_Transform(graphPtr->axisArr[Y1_AXIS], y));
+	Tcl_AppendElement(graphPtr->interp, string);
+    }
     return TCL_OK;
 }
 
+/*
+ *--------------------------------------------------------------
+ *
+ * AdjustAxisPointers --
+ *
+ *	Sets the axis pointers according to whether the axis is
+ *	inverted on not.  The axis locations are also reset.
+ *
+ * Results:
+ *	None.
+ *
+ *--------------------------------------------------------------
+ */
+static void
+AdjustAxisPointers(graphPtr)
+    Graph *graphPtr;		/* Graph widget record */
+{
+    if (graphPtr->inverted) {
+	graphPtr->bottomAxis = graphPtr->axisArr[Y1_AXIS];
+	graphPtr->leftAxis = graphPtr->axisArr[X1_AXIS];
+	graphPtr->topAxis = graphPtr->axisArr[Y2_AXIS];
+	graphPtr->rightAxis = graphPtr->axisArr[X2_AXIS];
+    } else {
+	graphPtr->bottomAxis = graphPtr->axisArr[X1_AXIS];
+	graphPtr->leftAxis = graphPtr->axisArr[Y1_AXIS];
+	graphPtr->topAxis = graphPtr->axisArr[X2_AXIS];
+	graphPtr->rightAxis = graphPtr->axisArr[Y2_AXIS];
+    }
+    graphPtr->bottomAxis->location = BOTTOM_AXIS;
+    graphPtr->leftAxis->location = LEFT_AXIS;
+    graphPtr->topAxis->location = TOP_AXIS;
+    graphPtr->rightAxis->location = RIGHT_AXIS;
+}
+
 /*
  *----------------------------------------------------------------------
  *
@@ -481,6 +531,8 @@ CreateGraph(interp, parent, pathName, type)
 	    goto error;
 	}
     }
+    AdjustAxisPointers(graphPtr);
+
     if (Blt_CreatePostScript(graphPtr) != TCL_OK) {
 	goto error;
     }
@@ -537,7 +589,9 @@ ConfigureGraph(graphPtr, argc, argv, flags)
     GC newGC;
     XGCValues gcValues;
     unsigned long gcMask;
+    int oldFlag;
 
+    oldFlag = graphPtr->inverted;
     if (Tk_ConfigureWidget(graphPtr->interp, graphPtr->tkwin, configSpecs,
 	    argc, argv, (char *)graphPtr, flags) != TCL_OK) {
 	return TCL_ERROR;
@@ -584,6 +638,11 @@ ConfigureGraph(graphPtr, argc, argv, flags)
 	Tk_FreeGC(graphPtr->display, graphPtr->intGC);
     }
     graphPtr->intGC = newGC;
+
+    if (oldFlag != graphPtr->inverted) {
+	AdjustAxisPointers(graphPtr);
+	Blt_ComputeAxes(graphPtr);
+    }
     /*
      * Reconfigure the crosshairs in case the plotting area's
      * background color changed
@@ -686,7 +745,6 @@ GraphWidgetCmd(clientData, interp, argc, argv)
     unsigned int length;
     unsigned int flags;
     GraphClassType type;
-    GraphAxis *axisPtr;
 
     if (argc < 2) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
@@ -720,20 +778,20 @@ GraphWidgetCmd(clientData, interp, argc, argv)
 	result = Blt_TagCmd(graphPtr, argc, argv);
     } else if ((c == 'x') && (length > 1) &&
 	(strncmp(argv[1], "xaxis", length) == 0)) {
-	axisPtr = graphPtr->axisArr[X1];
-	result = Blt_AxisCmd(graphPtr, axisPtr, argc, argv, flags);
+	result = Blt_AxisCmd(graphPtr, graphPtr->axisArr[X1_AXIS], argc, argv,
+	    flags);
     } else if ((c == 'x') && (length > 1) &&
 	(strncmp(argv[1], "x2axis", length) == 0)) {
-	axisPtr = graphPtr->axisArr[X2];
-	result = Blt_AxisCmd(graphPtr, axisPtr, argc, argv, flags);
+	result = Blt_AxisCmd(graphPtr, graphPtr->axisArr[X2_AXIS], argc, argv,
+	    flags);
     } else if ((c == 'y') && (length > 1) &&
 	(strncmp(argv[1], "yaxis", length) == 0)) {
-	axisPtr = graphPtr->axisArr[Y1];
-	result = Blt_AxisCmd(graphPtr, axisPtr, argc, argv, flags);
+	result = Blt_AxisCmd(graphPtr, graphPtr->axisArr[Y1_AXIS], argc, argv,
+	    flags);
     } else if ((c == 'y') && (length > 1) &&
 	(strncmp(argv[1], "y2axis", length) == 0)) {
-	axisPtr = graphPtr->axisArr[Y2];
-	result = Blt_AxisCmd(graphPtr, axisPtr, argc, argv, flags);
+	result = Blt_AxisCmd(graphPtr, graphPtr->axisArr[Y2_AXIS], argc, argv,
+	    flags);
     } else if ((c == 'l') && (length > 1) &&
 	(strncmp(argv[1], "legend", length) == 0)) {
 	result = Blt_LegendCmd(graphPtr, argc, argv);
