@@ -201,16 +201,27 @@ typedef struct {
  * -------------------------------------------------------------------
  */
 typedef enum AxisTypes {
-    X1, Y1, X2, Y2
+    X1_AXIS, Y1_AXIS, X2_AXIS, Y2_AXIS
 } AxisType;
 
-#define AXIS_X1_FLAG		(1<<X1)
-#define AXIS_Y1_FLAG		(1<<Y1)
-#define AXIS_X2_FLAG		(1<<X2)
-#define AXIS_Y2_FLAG		(1<<Y2)
-#define AXIS_X_MASK		(AXIS_X1_FLAG|AXIS_X2_FLAG)
-#define AXIS_Y_MASK		(AXIS_Y1_FLAG|AXIS_Y2_FLAG)
-#define AXIS_TYPE_MASK		(AXIS_Y_MASK|AXIS_X_MASK)
+#define AXIS_MASK(a)	(1<<((a)->type))
+#define X_AXIS(a)    	(!((a)->type&1))
+#define Y_AXIS(a)	((a)->type&1)
+
+/* AxisFlags used by elements and tags */
+#define X1_AXIS_MASK	(1<<X1_AXIS)
+#define Y1_AXIS_MASK	(1<<Y1_AXIS)
+#define X2_AXIS_MASK	(1<<X2_AXIS)
+#define Y2_AXIS_MASK	(1<<Y2_AXIS)
+
+#define STD_AXES_MASK	(X1_AXIS_MASK|Y1_AXIS_MASK)
+#define ANY_X_MASK	(X1_AXIS_MASK|X2_AXIS_MASK)
+#define ANY_Y_MASK	(Y1_AXIS_MASK|Y2_AXIS_MASK)
+
+typedef enum AxisLocations {
+    BOTTOM_AXIS, LEFT_AXIS, TOP_AXIS, RIGHT_AXIS
+} AxisLocation;
+
 
 /*
  * -------------------------------------------------------------------
@@ -229,7 +240,8 @@ typedef void (AxisLayoutProc) _ANSI_ARGS_((Graph *, GraphAxis *));
 typedef void (AxisDestroyProc) _ANSI_ARGS_((Graph *, GraphAxis *));
 
 struct GraphAxis {
-    unsigned int flags;		/* Axis flags */
+    enum AxisTypes type;
+    enum AxisLocations location;/* Location of the axis: right, left, etc. */
     int logScale;		/* If non-zero, scale values
 				 * logarithmically */
     int mapped;			/* If non-zero, display the axis */
@@ -352,6 +364,7 @@ struct Graph {
     GraphPostScript *postscript;/* PostScript options: see bltGrPS.c */
     GraphLegend *legendPtr;	/* Legend information: see bltGrLegd.c */
     GraphAxis *axisArr[4];	/* Coordinate axis info: see bltGrAxis.c */
+    GraphAxis *bottomAxis, *topAxis, *leftAxis, *rightAxis;
     GraphCrosshairs *crosshairs;/* Crosshairs information: see
 				   bltGrHairs.c */
 
@@ -383,6 +396,8 @@ struct Graph {
 
     XColor *intBgColorPtr;	/* Color of plot surface */
     double barWidth;		/* Scale factor for the width of bar */
+    int inverted;		/* If non-zero, indicates the x and y axis
+				 * positions should be inverted. */
     double avgSymSize;		/* Average size of a symbol */
 
     char *title;		/* Graph title */
